@@ -107,13 +107,8 @@ ajax "/ajax/control/admin/snapshot_req" => require_role admin => sub {
     send_error('Bad device', 400)
       if ! $device or $device->addr eq '0.0.0.0';
 
-    # unfortunately mibs data is required to do a snapshot
-    # will bloat the DB by about 300MB, TODO: find a way to avoid this.
-    add_job('loadmibs')
-      if not schema(vars->{'tenant'})->resultset('SNMPObject')->count();
-    
-    # will store for download and for browsing
-    add_job('snapshot', $device->addr, undef, 'db') or send_error('Bad device', 400);
+    # will store for download, and for browsing only if loadmibs has been run
+    add_job('snapshot', $device->addr) or send_error('Bad device', 400);
 };
 
 get "/ajax/content/admin/snapshot_get" => require_role admin => sub {
@@ -121,7 +116,33 @@ get "/ajax/content/admin/snapshot_get" => require_role admin => sub {
     send_error('Bad device', 400)
       if ! $device or $device->addr eq '0.0.0.0';
 
-    my $content = schema(vars->{'tenant'})->resultset('DeviceSnapshot')->find($device->addr)->cache;
+    my @rows = schema(vars->{'tenant'})->resultset('DeviceBrowser')
+                                       ->search({
+                                          ip => $device->addr,
+                                          -bool => \q{ jsonb_typeof(value) = 'array' },
+                                       })->hri->all;
+
+    send_error('No snapshot', 400)
+      if 0 == scalar @rows;
+
+    my @snmpwalk = ();
+    foreach my $row (@rows) {
+        $row->{value} = (@{ from_json($row->{value}) })[0];
+        if (ref {} eq ref $row->{value}) {
+            foreach my $k (keys %{ $row->{value} }) {
+                push @snmpwalk, [($row->{oid} .'.'. $k), $row->{value}->{$k}];
+            }
+        }
+        else {
+            push @snmpwalk, [$row->{oid}, $row->{value}];
+        }
+    }
+
+    # .1.3.6.1.2.1.25.5.1.1.1.38441 = INTEGER: 40
+    my $content = join "\n",
+      map {sprintf '%s = BASE64: %s', $_->[0], $_->[1]} @snmpwalk;
+    $content .= "\n";
+
     send_file( \$content, content_type => 'text/plain', filename => ($device->addr .'-snapshot.txt') );
 };
 
@@ -130,7 +151,6 @@ ajax "/ajax/control/admin/snapshot_del" => require_role setting('defanged_admin'
     send_error('Bad device', 400)
       if ! $device or $device->addr eq '0.0.0.0';
 
-    schema(vars->{'tenant'})->resultset('DeviceSnapshot')->find($device->addr)->delete;
     schema(vars->{'tenant'})->resultset('DeviceBrowser')->search({ip => $device->addr})->delete;
 };
 
